## v0.3.1 (2024-11-26)

### Fix

- **ci**: Update from deprecated macos-12 to macos-13

## v0.3.0 (2024-11-26)

### Feat

- Add pre-commit
- Optimized find_ignoreds fn performance
- Add exclude_ignoreds arg feature to exclude some paths
- Upgrade deps for breaking changes

### Fix

- **ci**: failed to build pyo3

## v0.2.0 (2024-01-30)

### Feat

- Release v0.2.0
- Optimize duplicate paths

## v0.1.0 (2024-01-30)

### Feat

- **ci**: Add multi python versions build
- Refactor the find_ignoreds fn using `ignore` instead of `git2` lib
- Init
